// LGT8F328P "EEPROM" test
// PhilG's frequency hopping code uses a few bytes of EEPROM
// (transmitter less than 30 bytes, receiver even fewer)
// LGT8F doesn't have a real EEPROM but emulates one using part of its FLASH memory
// test if it works.  This is using the Nulllab board library
// ################important!  Set EEROM size: option in Tools menu to 1KB###################
// ceptimus 2022-06-30

#include <EEPROM.h>
// just read and print to the Serial monitor, a 30-byte string from the EEPROM
// if it's not what we expect (First run of program), then write that string to the EEPROM
// the user can then power down, maybe run other sketches that don't use EEPROM, etc. Then run this again to see if the data was retained.

const char testString[] = "This is the string that we wrote!";  // 34 characters, including the end-of-string '\0' character

void setup() {
  char readFromEEPROM[34];

  Serial.begin(115200);
  for (uint8_t i = 0; i < 34; i++) {
    readFromEEPROM[i] = EEPROM.read(i);
  }
  if (strcmp(readFromEEPROM, testString)) {
    Serial.print("EEPROM didn't contain expected string. Maybe this is the first time you've run the program?\n");
    delay(3000); // time to read message, in case printing what we read messes up the display
    Serial.print("EEPROM contained ***[");
    Serial.print(readFromEEPROM);
    Serial.print("]***\nNow writing string to EEPROM...");
    for (uint8_t i = 0; i < 34; i++) {
      EEPROM.write(i, testString[i]);
    }
    Serial.print("\nAll done!  Cycle power to test.\n");
  } else {
    Serial.print("EEPROM contained ***[");
    Serial.print(readFromEEPROM);
    Serial.print("]***  A perfect result!\n");
  }
}

void loop() {
}
